#####################
Henson |build status|
#####################

.. |build status| image:: https://travis-ci.org/iheartradio/Henson.svg?branch=master
   :target: https://travis-ci.org/iheartradio/Henson

.. image:: docs/_static/logo.png
   :width: 400
   :height: 400
   :align: center

A framework for running a Python service driven by a consumer.

* `Documentation <https://henson.rtfd.org>`_
* `Installation <https://henson.readthedocs.org/en/latest/#installation>`_
* `Changelog <https://henson.readthedocs.org/en/latest/changes.html>`_
* `Source <https://github.com/iheartradio/Henson>`_
